/* Dad.java
 *
 * created: Mon Jul 12 1999
 *
 * This file is part of Artemis
 *
 * Copyright (C) 1999,2000,2001  Genome Research Limited
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 *
 *  "Axiom:        Any non-trivial program contains some bugs
 *   Corollary:    If a program has no bugs, it is useless"
 *
 * $Header: /nfs/pathsoft/repository/agctimpl/Dad.java,v 1.16 2001/09/13 13:39:33 kmr Exp $
 */

import diana.*;
import diana.components.*;
import diana.sequence.*;

import uk.ac.sanger.pathogens.*;

import uk.ac.sanger.pathogens.embl.QualifierInfoVector;
import uk.ac.sanger.pathogens.embl.QualifierInfoException;
import uk.ac.sanger.pathogens.embl.EntryInformation;
import uk.ac.sanger.pathogens.embl.EntryInformationException;
import uk.ac.sanger.pathogens.embl.ReadFormatException;
import uk.ac.sanger.pathogens.embl.InvalidRelationException;
import uk.ac.sanger.pathogens.embl.DocumentEntryFactory;

import java.awt.*;
import java.awt.event.*;
import java.io.*;

/**
 *  This class contains the main () method for "Dual Artemis Display" AKA
 *  "Artemis Comparison Tool".
 *
 *  @author Kim Rutherford
 *  @version $Id: Dad.java,v 1.16 2001/09/13 13:39:33 kmr Exp $
 **/

public class Dad {
  /**
   *  Version String use for banner messages and title bars.
   **/
  public static final String version = "Release 2 [Dev]";

  /**
   *  Main entry point for ACT
   **/
  public static void main (final String [] args) {
    final ActMain main_window = new ActMain ();

    main_window.setVisible (true);

    try {
      final InputStreamProgressListener process_listener =
        main_window.getInputStreamProgressListener ();

      if (args.length % 2 == 1 && args.length >= 3) {
        if (args.length == 3) {
          ActMain.makeComparator (main_window,
                                  process_listener,
                                  args[0], args[1], args[2]);
        } else {
          ActMain.makeMultiComparator (main_window,
                                       process_listener,
                                       args);
        }
      } else {
        if (args.length != 0) {
          System.err.println ("Error - this program needs either no " +
                              " arguments or an odd number\n" +
                              "(3 or more):");
          System.err.println ("   act sequence_1 comparison_data sequence_2");
          System.err.println ("or");
          System.err.println ("   act");
          System.exit (1);
        }
      }
    } catch (IOException e) {
      final String message = "error while reading: " + e.getMessage ();
      new MessageFrame (message);
    } catch (OutOfRangeException e) {
      new MessageFrame ("read failed with an \"out of range\" error: " +
                        e.getMessage ());
    } catch (EntryInformationException e) {
      new MessageFrame ("read failed: " + e.getMessage ());
    }
  }
}

